@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "configdialog.h"
 #include "configdialog_p.h"
@@ -29,7 +17,8 @@
 Palapeli::TriggerComboBox::TriggerComboBox(QWidget* parent)
 	: KComboBox(parent)
 {
-	connect(this, SIGNAL(currentIndexChanged(int)), SLOT(handleCurrentIndexChanged(int)));
+	connect(this, QOverload<int>::of(&QComboBox::currentIndexChanged),
+                this, &TriggerComboBox::handleCurrentIndexChanged);
 }
 
 QString Palapeli::TriggerComboBox::backgroundKey() const
@@ -48,8 +37,8 @@ void Palapeli::TriggerComboBox::handleCurrentIndexChanged(int index)
 {
 	Q_UNUSED(index)
 	const QString key = backgroundKey();
-	emit backgroundKeyChanged(key);
-	emit itemTypeChanged(key == QLatin1String("__color__"));
+	Q_EMIT backgroundKeyChanged(key);
+	Q_EMIT itemTypeChanged(key == QLatin1String("__color__"));
 }
 
 //END Palapeli::TriggerComboBox
@@ -75,8 +64,8 @@ Palapeli::ConfigDialog::ConfigDialog(QWidget* parent)
 	//setup page "Mouse interaction"
 	addPage(m_triggerPage, i18n("Mouse interaction"))->
 				setIcon(QIcon::fromTheme( QStringLiteral( "input-mouse" )));
-	connect(m_triggerPage, SIGNAL(associationsChanged()),
-			       SLOT(updateButtons()));
+	connect(m_triggerPage, &TriggerConfigWidget::associationsChanged,
+	        this, &ConfigDialog::updateButtons);
 }
 
 bool Palapeli::ConfigDialog::hasChanged()
@@ -127,8 +116,8 @@ void Palapeli::ConfigDialog::setupSolutionAreaComboBox()
 	b->insertItem(BottomLeft,  i18n("Bottom Left"),  BottomLeft);
 	b->insertItem(BottomRight, i18n("Bottom Right"), BottomRight);
 	b->setCurrentIndex(Settings::solutionArea());
-	connect(b,    SIGNAL(currentIndexChanged(int)),
-		this, SLOT(solutionAreaChange(int)));
+	connect(b,    QOverload<int>::of(&QComboBox::currentIndexChanged),
+		this, &ConfigDialog::solutionAreaChange);
 }
 
 void Palapeli::ConfigDialog::solutionAreaChange(int index)
