@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009, 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "view.h"
 #include "interactormanager.h"
@@ -41,7 +29,7 @@ const int DefaultDelta = 120;
 
 Palapeli::View::View()
 	: m_interactorManager(new Palapeli::InteractorManager(this))
-	, m_scene(0)
+	, m_scene(nullptr)
 	, m_zoomLevel(MinimumZoomLevel)
 	, m_closeUpLevel(MaximumZoomLevel)
 	, m_distantLevel(MinimumZoomLevel)
@@ -62,6 +50,7 @@ Palapeli::View::View()
 // IDW test.
 void Palapeli::View::logSceneChange(const QRectF &r)
 {
+    Q_UNUSED(r);
 	// qCDebug(PALAPELI_LOG) << "View::logSceneChange" << r << "View size" << this->size();
 }
 
@@ -150,9 +139,9 @@ void Palapeli::View::moveViewportBy(const QPointF& sceneDelta)
 
 void Palapeli::View::teleportPieces(Piece* pieceUnder, const QPointF& scenePos)
 {
-	qCDebug(PALAPELI_LOG) << "TELEPORT: pieceUnder" << (pieceUnder != 0)
+	qCDebug(PALAPELI_LOG) << "TELEPORT: pieceUnder" << (pieceUnder != nullptr)
 		 << "scenePos" << scenePos;
-	emit teleport(pieceUnder, scenePos, this);
+	Q_EMIT teleport(pieceUnder, scenePos, this);
 }
 
 void Palapeli::View::zoomBy(int delta)
@@ -196,7 +185,7 @@ void Palapeli::View::zoomTo(int level)
 	setTransform(t);
 	// Save and report changes.
 	m_zoomLevel = level;
-	emit zoomLevelChanged(m_zoomLevel);
+	Q_EMIT zoomLevelChanged(m_zoomLevel);
 	// In a mouse-centered zoom, lock the pointer onto the scene position.
 	if (m_adjustPointer) {
 		// Let the new view settle down before checking the mouse.
@@ -283,7 +272,7 @@ void Palapeli::View::setCloseUp(bool onOff)
 
 void Palapeli::View::handleNewPieceSelection()
 {
-	emit newPieceSelectionSeen(this);
+	Q_EMIT newPieceSelectionSeen(this);
 }
 
 qreal Palapeli::View::calculateCloseUpScale()
@@ -341,9 +330,9 @@ void Palapeli::View::puzzleStarted()
 
 	// Don't readjust the zoom. Just set the slider pointer.
 	m_zoomLevel = level;		// Make zoomTo() ignore the back-signal.
-	emit zoomLevelChanged(level);
+	Q_EMIT zoomLevelChanged(level);
 	centerOn(sceneRect().center());	// Center the view of the whole puzzle.
-	emit zoomAdjustable(true);	// Enable the ZoomWidget.
+	Q_EMIT zoomAdjustable(true);	// Enable the ZoomWidget.
 
 	// Explain autosaving.
 	KMessageBox::information(window(), i18n("Your progress is saved automatically while you play."), i18nc("used as caption for a dialog that explains the autosave feature", "Automatic saving"), QStringLiteral("autosave-introduction"));
@@ -357,7 +346,7 @@ void Palapeli::View::startVictoryAnimation()
 	animation->setEndValue(m_scene->extPiecesBoundingRect());
 	animation->setDuration(1000);
 	animation->start(QAbstractAnimation::DeleteWhenStopped);
-	emit zoomAdjustable(false);
+	Q_EMIT zoomAdjustable(false);
 }
 
 
